.. _get-started:

===============
Get started
===============

On our `official homepage <https://www.nb.no/dh-lab/>`_ (in Norwegian), you can view and run `example jupyter notebooks <https://www.nb.no/dh-lab/digital-tekstanalyse/>`_
without installing anything.

Below you'll find installation instructions, and examples of using the `dhlab <https://pypi.org/project/dhlab/>`_ python package.


.. toctree::
   :name: get-started-toc
   :titlesonly:

   docs_ways_to_use
   docs_installation
   docs_notebooks
   docs_example_use

